@@ -341,6 +341,31 @@ extern "C"
    */
   ykpiv_rc ykpiv_util_read_cert(ykpiv_state *state, uint8_t slot, uint8_t **data, size_t *data_len);
 
+  /**
+   * Decompresses a certificate if it was compressed
+   *
+   * @param buf Fetched certificate data
+   * @param buf_len Length of fetched certificate data
+   * @param certdata Raw certificate bytes
+   * @param certdata_len Length of raw certificate bytes
+   *
+   * @return Error code
+   */
+  ykpiv_rc ykpiv_util_get_certdata(uint8_t *buf, size_t buf_len, uint8_t* certdata, size_t *certdata_len);
+
+  /**
+   * Construct cert data to store
+   *
+   * @param data Raw certificate data
+   * @param data_len Length of raw certificate data
+   * @param compress_info Certificate compression state
+   * @param certdata Constructed certificate data
+   * @param certdata_len Length of constructed certificate data
+   *
+   * @return Error code
+   */
+  ykpiv_rc ykpiv_util_write_certdata(uint8_t *data, size_t data_len, uint8_t compress_info, uint8_t* certdata, size_t *certdata_len);
+
   /**
    * Write a certificate to a given slot
    *
